@@ -1,5 +1,5 @@
 from .env import EnvHelper
-from .paginator import CustomPaginator
+from .paginator import CustomPaginator  # noqa
 from .redirect import RedirectHelper
 
 __all__ = ["RedirectHelper", "EnvHelper", "CustomPaginator"]
