@@ -25,6 +25,7 @@ __all__ = [
     "ALLOWED_HOSTS",  # by env
     "LANGUAGE_CODE",  # by env
     "TIME_ZONE",  # by env
+    "USE_TZ",  # always open
     "MEDIA_URL",  # by env
     "MEDIA_ROOT",  # by env
     "STATIC_URL",  # by env
@@ -61,9 +62,11 @@ LANGUAGE_CODE = os.getenv("DJANGO_LANGUAGE_CODE", "zh-Hans")
 
 TIME_ZONE = os.getenv("DJANGO_TIME_ZONE", "Asia/Shanghai")
 
-MEDIA_URL = os.getenv("DJANGO_MEDIA_URL", "media/")
+USE_TZ = True
 
-STATIC_URL = os.getenv("DJANGO_STATIC_URL", "static/")
+MEDIA_URL = os.getenv("DJANGO_MEDIA_URL", "/media/")
+
+STATIC_URL = os.getenv("DJANGO_STATIC_URL", "/static/")
 
 #################################################################################
 # this is ugly hack
